@@ -48,8 +48,6 @@ def examine_directory(loader, dirname, destname=None):
             package.
         - a Metadata object.
         - a Resources object.
-
-    ### ignore .pyc and ~ files in contents? Or warn about them?
     """
     
     # Read in the source Metadata file (which may be missing or
@@ -243,7 +241,24 @@ def examine_directory(loader, dirname, destname=None):
             if ((not mods) and (file in [pload.Filename_Metadata, pload.Filename_Resources])):
                 # Ignore Metadata and Resources entirely
                 continue
-                
+
+            filelow = file.lower()
+            if (filelow.endswith('.pyc')):
+                # Package directories always wind up with .pyc files;
+                # silently ignore
+                continue
+
+            if (filelow.endswith('.pyo')
+                or filelow.endswith('.so')
+                or filelow.endswith('.o')):
+                # Noisily ignore any code file that is not transparent
+                warning(dirname, 'skipping file which looks like compiled code: ' + file)
+                continue
+
+            if (filelow.endswith('~')):
+                # Print a warning, but allow it
+                warning(dirname, 'file looks temporary: ' + file)
+
             # Create the real filename (readable in dirname)
             realfilename = os.path.join(dirname, *(mods + [file]))
             # Create the canonical (forward-slash) filename.
@@ -451,14 +466,33 @@ def resolve_dependency_metadata(dirname, pkgname, pkgvers,
     # Add the dependencies to the metadata.
     ls = import_record.get( (pkgname, pkgvers) )
     if (ls):
+        entls = []
         for (reqname, reqspec) in ls:
             if (reqspec is None):
-                metadata.add('boodler.requires', reqname)
+                entls.append( ('boodler.requires', reqname) )
             elif (isinstance(reqspec, version.VersionSpec)):
-                metadata.add('boodler.requires', reqname+' '+str(reqspec))
+                entls.append( ('boodler.requires', reqname+' '+str(reqspec)) )
             elif (isinstance(reqspec, version.VersionNumber)):
-                metadata.add('boodler.requires_exact', reqname+' '+str(reqspec))
+                entls.append( ('boodler.requires_exact', reqname+' '+str(reqspec)) )
+        for (key, val) in entls:
+            if (val in metadata.get_all(key)):
+                # This exact line is already present.
+                warning(dirname, 'skipping dependency which already exists in Metadata: "' + key + ': ' + val + '"')
+                continue
+            metadata.add(key, val)
 
+    # Warn about packages which appear in the dependencies twice.
+    dic = {}
+    for val in (metadata.get_all('boodler.requires') + metadata.get_all('boodler.requires_exact')):
+        ls = val.split()
+        if (ls):
+            pinfo.dict_accumulate(dic, ls[0], True)
+    for reqname in dic.keys():
+        val = len(dic[reqname])
+        if (val > 1):
+            warning(dirname, 'package dependency appears in ' + str(val)
+                + ' different forms: ' + reqname)
+            
     revmap = {}
         
     for key in context.agents:
